aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/algorithm.hxx
diff options
context:
space:
mode:
Diffstat (limited to 'libbuild2/algorithm.hxx')
-rw-r--r--libbuild2/algorithm.hxx10
1 files changed, 5 insertions, 5 deletions
diff --git a/libbuild2/algorithm.hxx b/libbuild2/algorithm.hxx
index 0f981a9..b7f6809 100644
--- a/libbuild2/algorithm.hxx
+++ b/libbuild2/algorithm.hxx
@@ -546,13 +546,13 @@ namespace build2
// the injected target or NULL. Normally this function is called from the
// rule's apply() function.
//
// As an extension, this function will also search for an existing fsdir{}
// prerequisite for the directory and if one exists, return that (even if
// the target is in src tree). This can be used, for example, to place
// output into an otherwise non-existent directory.
//
LIBBUILD2_SYMEXPORT const fsdir*
- inject_fsdir (action, target&, bool parent = true);
+ inject_fsdir (action, target&, bool prereq = true, bool parent = true);
// Execute the action on target, assuming a rule has been matched and the
// recipe for this action has been set. This is the synchrounous executor
@@ -546,13 +546,13 @@ namespace build2
// rule's apply() function.
//
- // As an extension, this function will also search for an existing fsdir{}
- // prerequisite for the directory and if one exists, return that (even if
- // the target is in src tree). This can be used, for example, to place
- // output into an otherwise non-existent directory.
+ // As an extension, unless prereq is false, this function will also search
+ // for an existing fsdir{} prerequisite for the directory and if one exists,
+ // return that (even if the target is in src tree). This can be used, for
+ // example, to place output into an otherwise non-existent directory.
//
LIBBUILD2_SYMEXPORT const fsdir*